@@ -1,6 +1,6 @@
 package Pod::Weaver;
 BEGIN {
-  $Pod::Weaver::VERSION = '3.101270';
+  $Pod::Weaver::VERSION = '3.101450';
 }
 use Moose;
 # ABSTRACT: weave together a Pod document from an outline
@@ -8,6 +8,7 @@ use Moose;
 use namespace::autoclean;
 
 
+use File::Spec;
 use Log::Dispatchouli 1.100710; # proxy
 use Moose::Autobox 0.10;
 use Pod::Elemental 0.100220;
@@ -97,10 +98,9 @@ sub new_with_default_config {
 sub new_from_config {
   my ($class, $arg, $new_arg) = @_;
   
-  my ($sequence) = Pod::Weaver::Config::Finder->new->read_config({
-    root     => $arg->{root}     || '.',
-    basename => $arg->{basename} || 'weaver',
-  });
+  my $root = $arg->{root} || '.';
+  my $name = File::Spec->catfile($root, 'weaver');
+  my ($sequence) = Pod::Weaver::Config::Finder->new->read_config($name);
 
   return $class->new_from_config_sequence($sequence, $new_arg);
 }
@@ -163,7 +163,7 @@ Pod::Weaver - weave together a Pod document from an outline
 
 =head1 VERSION
 
-version 3.101270
+version 3.101450
 
 =head1 SYNOPSIS
 
