@@ -1,11 +1,11 @@
 package Pod::Weaver::Config;
 BEGIN {
-  $Pod::Weaver::Config::VERSION = '3.101270';
+  $Pod::Weaver::Config::VERSION = '3.101450';
 }
 use Moose::Role;
 # ABSTRACT: stored configuration loader role
 
-use Config::MVP 0.093120;
+use Config::MVP 1;
 with q(Config::MVP::Reader) => { -excludes => 'build_assembler' };
 
 use Pod::Weaver::Config::Assembler;
@@ -35,7 +35,7 @@ Pod::Weaver::Config - stored configuration loader role
 
 =head1 VERSION
 
-version 3.101270
+version 3.101450
 
 =head1 DESCRIPTION
 
